package com.jbtravel.domain;

import java.io.Serializable;
import java.math.BigDecimal;
import java.util.ArrayList;
import java.util.HashSet;
import java.util.List;
import java.util.Set;

/**
 * The persistent class for the reservation database table.
 * 
 */
public class Reservation implements Serializable {
	private static final long serialVersionUID = 1L;

	private Integer reservationid;

	private Integer checkedin;

	private String comment;
	
	private boolean upgradeclass;
	private boolean upgrademeal;
	private boolean upgradecomfort;
	private boolean bagcheck;
	private Integer bags = 0;
	private boolean upgradeentertainment;
	private boolean upgradedrink;
	private boolean tripinsurance;
	
	private ReservationStatusType status = ReservationStatusType.NEW;

	// bi-directional many-to-one association to Flight
	private Flight flight;

	// bi-directional many-to-one association to Seat
	private Seat seat;

	// bi-directional many-to-one association to User
	private User user;

	// bi-directional many-to-one association to ValMealtype
	private ValMealtype valMealtype;
	
	private Set<Fee> fees = new HashSet<Fee>();

	public Reservation() {
	}

	public Integer getReservationid() {
		return this.reservationid;
	}

	public void setReservationid(Integer reservationid) {
		this.reservationid = reservationid;
	}

	public Integer getCheckedin() {
		return this.checkedin;
	}

	public void setCheckedin(Integer checkedin) {
		this.checkedin = checkedin;
	}

	public String getComment() {
		return this.comment;
	}

	public void setComment(String comment) {
		this.comment = comment;
	}

	public Flight getFlight() {
		return this.flight;
	}

	public void setFlight(Flight flight) {
		this.flight = flight;
	}

	public Seat getSeat() {
		return this.seat;
	}

	public void setSeat(Seat seat) {
		this.seat = seat;
	}

	public User getUser() {
		return this.user;
	}

	public void setUser(User user) {
		this.user = user;
	}

	public ValMealtype getValMealtype() {
		return this.valMealtype;
	}

	public void setValMealtype(ValMealtype valMealtype) {
		this.valMealtype = valMealtype;
	}

	public boolean isUpgradeclass() {
		return upgradeclass;
	}

	public void setUpgradeclass(boolean upgradeclass) {
		this.upgradeclass = upgradeclass;
	}

	public boolean isUpgrademeal() {
		return upgrademeal;
	}

	public void setUpgrademeal(boolean upgrademeal) {
		this.upgrademeal = upgrademeal;
	}

	public boolean isUpgradecomfort() {
		return upgradecomfort;
	}

	public void setUpgradecomfort(boolean upgradecomfort) {
		this.upgradecomfort = upgradecomfort;
	}

	public boolean isBagcheck() {
		return bagcheck;
	}

	public void setBagcheck(boolean bagcheck) {
		this.bagcheck = bagcheck;
	}

	public Integer getBags() {
		return bags;
	}

	public void setBags(Integer bags) {
		this.bags = bags;
	}

	public boolean isUpgradeentertainment() {
		return upgradeentertainment;
	}

	public void setUpgradeentertainment(boolean upgradeentertainment) {
		this.upgradeentertainment = upgradeentertainment;
	}

	public boolean isUpgradedrink() {
		return upgradedrink;
	}

	public void setUpgradedrink(boolean upgradedrink) {
		this.upgradedrink = upgradedrink;
	}

	public boolean isTripinsurance() {
		return tripinsurance;
	}

	public void setTripinsurance(boolean tripinsurance) {
		this.tripinsurance = tripinsurance;
	}
	
	public void addFee(Fee fee) {
		this.fees.add(fee);
	}
	
	public Set<Fee> getFees() {
		return this.fees;
	}

	public ReservationStatusType getStatus() {
		return status;
	}

	public void setStatus(ReservationStatusType status) {
		this.status = status;
	}
	
	public BigDecimal getTotalFees() {
		BigDecimal total = new BigDecimal("0.00");
		
		for (Fee fee : fees) {
			total = total.add(fee.getAmount());
		}
		
		return total;
	}
	
	public List<Fee> getFeeList() {
		List<Fee> fees = new ArrayList<Fee>();
		for(Fee fee: this.fees) {
			fees.add(fee);
		}
		return fees;
	}

}