package com.jbtravel.domain;

import java.io.Serializable;
import java.util.Set;

/**
 * The persistent class for the seat database table.
 * 
 */
public class Seat implements Serializable, Comparable<Seat> {
	private static final long serialVersionUID = 1L;

	private Integer seatid;

	private String seatname;
	private boolean exitrow = false;

	// bi-directional many-to-one association to Reservation
	private Set<Reservation> reservations;

	// bi-directional many-to-one association to Plane
	private Plane plane;

	// bi-directional many-to-one association to ValSeatclass
	private ValSeatclass valSeatclass;

	// bi-directional many-to-one association to ValSeattype
	private ValSeattype valSeattype;

	public Seat() {
	}

	public Integer getSeatid() {
		return this.seatid;
	}

	public void setSeatid(Integer seatid) {
		this.seatid = seatid;
	}

	public String getSeatname() {
		return this.seatname;
	}

	public void setSeatname(String seatname) {
		this.seatname = seatname;
	}

	public Set<Reservation> getReservations() {
		return this.reservations;
	}

	public void setReservations(Set<Reservation> reservations) {
		this.reservations = reservations;
	}

	public Plane getPlane() {
		return this.plane;
	}

	public void setPlane(Plane plane) {
		this.plane = plane;
	}

	public ValSeatclass getValSeatclass() {
		return this.valSeatclass;
	}

	public void setValSeatclass(ValSeatclass valSeatclass) {
		this.valSeatclass = valSeatclass;
	}

	public ValSeattype getValSeattype() {
		return this.valSeattype;
	}

	public void setValSeattype(ValSeattype valSeattype) {
		this.valSeattype = valSeattype;
	}

	@Override
	public int hashCode() {
		final int prime = 31;
		int result = 1;
		result = prime * result + ((seatid == null) ? 0 : seatid.hashCode());
		return result;
	}

	@Override
	public boolean equals(Object obj) {
		if (this == obj)
			return true;
		if (obj == null)
			return false;
		if (getClass() != obj.getClass())
			return false;
		Seat other = (Seat) obj;
		if (seatid == null) {
			if (other.seatid != null)
				return false;
		} else if (!seatid.equals(other.seatid))
			return false;
		return true;
	}

	public boolean isExitrow() {
		return exitrow;
	}

	public void setExitrow(boolean exitrow) {
		this.exitrow = exitrow;
	}

	@Override
	public int compareTo(Seat o) {
		// Convert seat names to numbers for comparison
		int mySeatNumber = getSeatSortNumber(this.getSeatname());
		int theirSeatNumber = getSeatSortNumber(o.getSeatname());
		
		return mySeatNumber - theirSeatNumber;
	}
	
	private int getSeatSortNumber(String seatname) {
		
		String seat = seatname.substring(seatname.length() - 1);
		int seatnumber = Integer.valueOf(seatname.substring(0, seatname.length() - 1)) * 10;
		switch(seat.charAt(0)) {
		case 'A' :
			seatnumber += 1;
			break;
		case 'B' :
			seatnumber += 2;
			break;
		case 'C' :
			seatnumber += 3;
			break;
		case 'D' :
			seatnumber += 4;
			break;
		case 'E' :
			seatnumber += 5;
			break;
		case 'F' :
			seatnumber += 6;
			break;
		case 'G' :
			seatnumber += 7;
			break;
		case 'H' :
			seatnumber += 8;
			break;
		case 'I' :
			seatnumber += 9;
			break;
		}
		return seatnumber;
	}



}